Response

Struct Response 

pub struct Response { /* private fields */ }
A response to be returned to the client. You do not always need to use this struct directly as endpoints can return anything implementing Responder. However this is the most flexible way to construct a reply, and it implements Responder (the “identity” implementation).

Implementations

Source

impl Response

pub fn ok() -> Self

Create an empty response with status code OK (200)

pub fn status(s: StatusCode) -> Self

Create an empty response with the given status code

pub fn set_status(&mut self, s: StatusCode)

Set the status code of a response

pub fn get_status(&self) -> StatusCode

Get the status code of a response

pub fn body(self, body: impl Into<Body>) -> Self

Set the body of the response

pub fn reader(self, r: impl AsyncRead + Send + 'static) -> Self

Set the body to an AsyncRead object

pub async fn path(self, path: impl AsRef<Path>) -> Result<Self>

Set the body to the content of a file given by a Path Also sets a content type by guessing the mime type from the path name

pub fn json(self, body: impl Serialize) -> Result<Self>

Set the body of the response to a JSON payload

pub fn form(self, body: impl Serialize) -> Result<Self>

Set the body of the response to form data

pub fn header<H: Header>(self, h: H) -> Self

Set a header (from the headers crate)

pub fn set_header<H: Header>(&mut self, h: H)

Set a header (without consuming self - useful outside of method chains)

pub fn raw_header<N, K>(self, name: N, key: K) -> Result<Self>

Set a raw header (from the http crate)

pub fn set_raw_header<N, K>(&mut self, name: N, key: K) -> Result<()>

Set a raw header (without consuming self)

pub fn into_inner(self) -> Response<Body>

Consume this response and return the inner hyper::Response